package Bundle::CMap;

$VERSION = '1.0.1';

1;

__END__

=head1 NAME

Bundle::CMap - Bundle of CMap requirements 

=head1 SYNOPSIS

perl -MCPAN -e 'install Bundle::CMap'

=head1 CONTENTS

Algorithm::Numerical::Sample

Apache::Htpasswd

Bit::Vector

Cache::Cache

CGI 

CGI::Session

Class::Base 

Clone 

Config::General

Data::Dumper

Date::Format

Data::Page

Data::Pageset

Data::Stag

DBI 1.50

Digest::MD5 2.36

File::Temp 0.16

Filesys::DfPortable

GD 2.32

GD::SVG 0.28

IO::Tee 0.64

Module::Build 0.28

Params::Validate

Regexp::Common

Storable

Template 2.14

Template::Plugin::Comma

Text::RecordParser v1.1.2

Time::ParseDate

Time::Piece

URI::Escape

XML::Parser::PerlSAX

XML::Simple

=head1 DESCRIPTION

This is a bundle of modules required by CMap.

=head1 AUTHOR

Ben Faga E<lt>faga@cshl.eduE<gt>
(Author of this bundle, not of the listed modules)

=cut
